import { HubConnection, HubConnectionBuilder, LogLevel } from '@microsoft/signalr';
import {AUTH_TOKEN_KEY} from "../constants/common";
import {IHttpConnectionOptions} from "@microsoft/signalr/src/IHttpConnectionOptions";
import {IChatMessage} from "../types/chat";

const URL = 'https://api.bbuddy.expert/api/hubs/chat'

const chatMessageMethodName = 'ReceiveMessage';
const chatUserStatusChangeMethodName = 'chatUserStatusChange';
const chatSeenMethodName = 'MessageWasRead';
const chatTypingMethodName = 'directTyping';
const sendChatTextMethodName = 'SendMessage';
const sendChatTypingMethodName = 'DirectIsTyping';
const serverError = 'Error';

const sendChatSeenMethodName = 'ConfirmMessageRead';
const sendChatMessagesSeenMethodName = 'ConfirmMessagesRead';


const joinChatMethodName = 'JoinChat';
const leaveChatMethodName = 'LeaveChat';

const joinChatsMethodName = 'JoinChats';
const leaveChatsMethodName = 'LeaveChats';
const chatsReceiveMessageMethodName = 'ChatsMessageCreated';

class SignalConnector {
    private connection: HubConnection;
    private events ={} as any;
    static instance: SignalConnector;
    constructor() {
        const options = {
            accessTokenFactory: () => localStorage.getItem(AUTH_TOKEN_KEY)
        } as IHttpConnectionOptions;
        this.connection = new HubConnectionBuilder()
            .withUrl(URL, options)
            .withAutomaticReconnect()
            .configureLogging(LogLevel.Debug)
            .build();
        this.connection.start().then(()=>{
            this.events?.onConnected(true)
            for (const k in this.events) {
                if (k != 'onConnected'){
                    this.connection.on(k, (payload: any) => {
                        this.events[k](payload);
                    });
                }
            }
        }).catch(err => console.log('SignalR Error', err));
    }
    public addListener = (name: string, func: any)=> {
        this.events[name] = func;
    }

    public closeConnection = () =>{
        this.connection.stop();
    }

    public newMessage = (message: IChatMessage) => {
        this.connection.invoke(sendChatTextMethodName, message).then(x => console.log('NewMsg',x))
    }
    public joinChat = (groupId: number) => {
        this.connection.invoke(joinChatMethodName, groupId, null).then(x => console.log(joinChatMethodName, x))
    }

    public joinChatPerson = (accId: number) => {
        return this.connection.invoke(joinChatMethodName, 0, accId)
    }

    public readMessages = (messagesId: number[]) => {
        this.connection.invoke(sendChatMessagesSeenMethodName, messagesId).then(x => console.log(sendChatMessagesSeenMethodName, x))
    }

    public static getInstance(): SignalConnector {
        if (!SignalConnector.instance)
            SignalConnector.instance = new SignalConnector();
        return SignalConnector.instance;
    }
}

export default SignalConnector.getInstance;